<?php
// classes/RedisManager.php

/**
 * @package Redis
 */

// 添加类型提示
/**
 * @class Redis
 */

class RedisManager
{
    private static $instance = null;
    /** @var \Redis */
    private $redis;

    private function __construct()
    {
        global $redis_host, $redis_port, $redis_password, $redis_prefix;

        $this->redis = new Redis();
        try {
            $this->redis->connect($redis_host, $redis_port);

            // 设置前缀，避免键名冲突
            if (!empty($redis_prefix)) {
                $this->redis->setOption(Redis::OPT_PREFIX, $redis_prefix);
            }

            // 如果有密码则进行认证
            if (!empty($redis_password)) {
                $this->redis->auth($redis_password);
            }

            $this->redis->ping();
        } catch (Exception $e) {
            error_log('Redis连接失败: ' . $e->getMessage());
            // 连接失败时不终止程序，而是继续执行不使用缓存
        }
    }

    public static function getInstance()
    {
        if (self::$instance === null) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    public function getRedis()
    {
        return $this->redis;
    }

    // 设置缓存
    public function set($key, $value, $expiry = 3600)
    {
        if (is_array($value)) {
            $value = json_encode($value);
        }
        return $this->redis->set($key, $value, $expiry);
    }

    // 获取缓存
    public function get($key)
    {
        $value = $this->redis->get($key);
        if ($value) {
            // 尝试解析JSON
            $json = json_decode($value, true);
            return ($json === null) ? $value : $json;
        }
        return null;
    }

    // 删除缓存
    public function delete($key)
    {
        return $this->redis->del($key);
    }

    // 检查键是否存在
    public function exists($key)
    {
        return $this->redis->exists($key);
    }

    // 添加一个检查Redis是否可用的方法
    public function isAvailable()
    {
        return $this->redis && $this->redis->ping() !== false;
    }

    // 删除匹配特定模式的所有缓存键
    public function deletePattern($pattern)
    {
        try {
            if (!$this->isAvailable()) {
                error_log("Redis不可用，无法删除模式键: $pattern");
                return false;
            }

            // 记录开始删除的日志
            global $redis_prefix;
            error_log("开始删除Redis缓存键，模式: $pattern，前缀: " . ($redis_prefix ?? 'none'));

            // 注意：当使用OPT_PREFIX时，keys命令的模式不会自动添加前缀
            // 所以我们需要手动处理，让keys匹配到实际存在的键
            $keys = $this->redis->keys($pattern);

            // 记录找到的键数量
            error_log("找到匹配 $pattern 的键: " . count($keys) . " 个");

            // 如果找不到键，尝试使用另一种方法 - 通过获取所有键然后手动过滤
            if (empty($keys)) {
                error_log("尝试通过获取所有键并手动过滤的方式");
                // 获取所有键
                $allKeys = $this->redis->keys('*');
                error_log("Redis中共有 " . count($allKeys) . " 个键");

                // 构建一个无前缀的模式进行匹配
                $patternWithoutPrefix = str_replace("*", ".*", $pattern);
                $patternRegex = "/^" . $patternWithoutPrefix . "/";

                // 手动过滤匹配的键
                $matchedKeys = [];
                foreach ($allKeys as $key) {
                    // 移除Redis前缀以便正确匹配
                    $keyWithoutPrefix = $redis_prefix ? substr($key, strlen($redis_prefix)) : $key;
                    if (preg_match($patternRegex, $keyWithoutPrefix)) {
                        $matchedKeys[] = $key;
                    }
                }

                $keys = $matchedKeys;
                error_log("通过手动过滤找到 " . count($keys) . " 个匹配键");
            }

            if (!empty($keys)) {
                $deletedCount = 0;
                foreach ($keys as $key) {
                    // 尝试删除每个键并记录结果
                    $result = $this->redis->del($key);
                    if ($result) {
                        $deletedCount++;
                        error_log("成功删除Redis键: $key");
                    } else {
                        error_log("删除Redis键失败: $key");
                    }
                }
                error_log("总共成功删除 $deletedCount 个Redis缓存键");
                return $deletedCount;
            }
            error_log("未找到匹配模式 $pattern 的Redis缓存键");
            return 0;
        } catch (Exception $e) {
            $errorMsg = '删除Redis缓存键失败: ' . $e->getMessage();
            error_log($errorMsg);
            error_log('异常追踪信息: ' . $e->getTraceAsString());
            return false;
        }
    }
}
