<?php
// 引入数据库配置文件
require_once '../config.php';

// 设置响应头为JSON
header('Content-Type: application/json');

// 清除Redis缓存
$redisManager = get_redis_instance();
$success = false;
$cleared = 0;
$debug_info = [];

if ($redisManager->isAvailable()) {
    $redis = $redisManager->getRedis();

    // 记录当前所有键
    try {
        $allKeys = $redis->keys('*');
        $debug_info['all_keys_count'] = count($allKeys);
        $debug_info['sample_keys'] = array_slice($allKeys, 0, 5);
    } catch (Exception $e) {
        $debug_info['keys_error'] = $e->getMessage();
    }

    // 直接尝试删除首页缓存键（带前缀）
    try {
        global $redis_prefix;
        $prefixed = !empty($redis_prefix);
        $debug_info['has_prefix'] = $prefixed;
        $debug_info['prefix'] = $redis_prefix;

        // 根据日志中的实际键名格式进行精确匹配
        $exactCacheKeys = [
            "inventory:product:1:10::" . md5(''),  // 完全匹配日志中的缓存键
            "inventory:product:1:10:0:" . md5(''), // 之前的键格式1
            "inventory:product:1:10:1:" . md5('')  // 之前的键格式2
        ];

        foreach ($exactCacheKeys as $key) {
            // 直接删除键（不考虑前缀，因为Redis会自动处理）
            if ($redis->exists($key)) {
                $redis->del($key);
                $cleared++;
                $success = true;
                $debug_info['deleted_exact_keys'][] = $key;
            }

            // 同时尝试删除带前缀的完整键（以防需要）
            $prefixedKey = ($redis_prefix ?? '') . $key;
            if ($redis->exists($prefixedKey)) {
                $redis->del($prefixedKey);
                $cleared++;
                $success = true;
                $debug_info['deleted_prefixed_keys'][] = $prefixedKey;
            }
        }

        // 使用模式匹配找出所有inventory相关的键
        $inventoryPatterns = [
            'inventory:product:*',
            '*inventory*product*'
        ];

        foreach ($inventoryPatterns as $pattern) {
            $keys = $redis->keys($pattern);
            if (!empty($keys)) {
                $debug_info['pattern_keys'][$pattern] = count($keys);
                foreach ($keys as $key) {
                    $redis->del($key);
                    $cleared++;
                    $success = true;
                }
            }
        }

        // 备用方案：查找并删除所有带inventory的键
        $inventoryKeys = array_filter($allKeys, function ($key) {
            return stripos($key, 'inventory') !== false;
        });

        $debug_info['found_inventory_keys'] = count($inventoryKeys);
        $debug_info['sample_inventory_keys'] = array_slice($inventoryKeys, 0, 5);

        foreach ($inventoryKeys as $key) {
            $redis->del($key);
            $cleared++;
            $success = true;
        }
    } catch (Exception $e) {
        $debug_info['delete_error'] = $e->getMessage();
        $debug_info['error_trace'] = $e->getTraceAsString();
    }

    // 最后确认所有键都已删除
    try {
        $remainingKeys = array_filter($redis->keys('*'), function ($key) {
            return stripos($key, 'inventory') !== false;
        });
        $debug_info['remaining_keys'] = count($remainingKeys);
        $debug_info['remaining_samples'] = array_slice($remainingKeys, 0, 5);
    } catch (Exception $e) {
        $debug_info['final_check_error'] = $e->getMessage();
    }
}

// 以JSON格式返回处理结果
$result = [
    'success' => $success,
    'cleared' => $cleared,
    'message' => $success ? "已清除 $cleared 个库存列表缓存" : "无需清除缓存或Redis不可用",
    'debug_info' => $debug_info,
    'need_refresh' => true // 告诉前端需要刷新页面
];

echo json_encode($result, JSON_UNESCAPED_UNICODE);
